==> haskell-monoid-subclasses-0.4.3-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-monoid-subclasses.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: monoid-subclasses
version: 0.4.3
id: monoid-subclasses-0.4.3-64OaxfJkDmoCi3HVQcUqFS
key: monoid-subclasses-0.4.3-64OaxfJkDmoCi3HVQcUqFS
license: BSD3
copyright: (c) 2013-2016 Mario Blazevic
maintainer: Mario Blazevic <blamario@yahoo.com>
homepage: https://github.com/blamario/monoid-subclasses/
synopsis: Subclasses of Monoid
description:
    A hierarchy of subclasses of '\''Monoid'\'' together with their instances for all data structures from base, containers, and
    text packages.
category: Data, Algebra, Text
author: Mario Blazevic
exposed: True
exposed-modules:
    Data.Monoid.Cancellative Data.Monoid.Factorial Data.Monoid.Null
    Data.Monoid.Textual Data.Monoid.Instances.ByteString.UTF8
    Data.Monoid.Instances.Concat Data.Monoid.Instances.Measured
    Data.Monoid.Instances.Positioned Data.Monoid.Instances.Stateful
abi: bb9fbde92f66bdf191cd445f9ddc740c
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/monoid-subclasses-0.4.3
library-dirs: /usr/lib/ghc-8.0.1/site-local/monoid-subclasses-0.4.3
data-dir: /usr/share/i386-linux-ghc-8.0.1/monoid-subclasses-0.4.3
hs-libraries: HSmonoid-subclasses-0.4.3-64OaxfJkDmoCi3HVQcUqFS
depends:
    base-4.9.0.0 bytestring-0.10.8.1 containers-0.5.7.1
    primes-0.2.1.0-K0eIDQpwpli2u6M20VlfZn
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
    vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
haddock-interfaces: /usr/share/doc/haskell-monoid-subclasses/html/monoid-subclasses.haddock
haddock-html: /usr/share/doc/haskell-monoid-subclasses/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monoid-subclasses-0.4.3.1-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-monoid-subclasses.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: monoid-subclasses
version: 0.4.3.1
id: monoid-subclasses-0.4.3.1-66jShhVzrLEHzXyBMv9poJ
key: monoid-subclasses-0.4.3.1-66jShhVzrLEHzXyBMv9poJ
license: BSD3
copyright: (c) 2013-2016 Mario Blazevic
maintainer: Mario Blazevic <blamario@yahoo.com>
homepage: https://github.com/blamario/monoid-subclasses/
synopsis: Subclasses of Monoid
description:
    A hierarchy of subclasses of '\''Monoid'\'' together with their instances for all data structures from base, containers, and
    text packages.
category: Data, Algebra, Text
author: Mario Blazevic
exposed: True
exposed-modules:
    Data.Monoid.Cancellative Data.Monoid.Factorial Data.Monoid.Null
    Data.Monoid.Textual Data.Monoid.Instances.ByteString.UTF8
    Data.Monoid.Instances.Concat Data.Monoid.Instances.Measured
    Data.Monoid.Instances.Positioned Data.Monoid.Instances.Stateful
abi: a8f27e57254158a13db51002cb3a9539
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/monoid-subclasses-0.4.3.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/monoid-subclasses-0.4.3.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/monoid-subclasses-0.4.3.1
hs-libraries: HSmonoid-subclasses-0.4.3.1-66jShhVzrLEHzXyBMv9poJ
depends:
    base-4.9.0.0 bytestring-0.10.8.1 containers-0.5.7.1
    primes-0.2.1.0-K0eIDQpwpli2u6M20VlfZn
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
    vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
haddock-interfaces: /usr/share/doc/haskell-monoid-subclasses/html/monoid-subclasses.haddock
haddock-html: /usr/share/doc/haskell-monoid-subclasses/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
